% Function reads .xlsx data and plots value for earnings
% from "Shipping Intelligence Network Timeseries" (Clarksons)

function [MR_earnings,year_earnings_MR,year_avg_mr,mr_avg_earnings] =...
    MR_Earnings(Plots)

fid = 'earnings.xlsx';
MR_earnings = xlsread(fid,'F7:F1587');
mr_avg_earnings = xlsread('earnings.xlsx','avg','C3:C64');
year_avg_mr = xlsread('earnings.xlsx','avg','B3:B64');

n_data_MR = length(MR_earnings);
year_start_MR = 1990+4/365; % 5 jan 1990
year_end_MR = 2020 + 106/366; % 17 april 2020
st = (year_end_MR - year_start_MR)/n_data_MR;
year_earnings_MR = year_start_MR:st:year_end_MR;
year_earnings_MR(:,n_data_MR) = [];



% Time Series Characteristics
kurt = kurtosis(MR_earnings);
skew = skewness(MR_earnings);
mdn = median(MR_earnings);
avg = mean(MR_earnings);
prc10 = prctile(MR_earnings,10);
prc90 = prctile(MR_earnings,90);

if Plots
   
    hold on
    plot(year_earnings_MR,MR_earnings,'color','black','LineWidth',0.1);
    plot(year_avg_mr,mr_avg_earnings,'-.','color','red','LineWidth',2);
    xlabel('Year')
    ylabel('Earnings [USD/day]')
    xlim([1989.99 2020.5]);
    legend('MR earnings','Annual average MR earnings');
    hold off
    
    R = price2ret(MR_earnings);
    figure
    histfit(R)
    xlabel('Weekly returns')
    ylabel('Frequency')
%     x0=10;
%     y0=10;
%     width=400;
%     height=300;
%     set(gcf,'position',[x0,y0,width,height]);
    figure
    qqplot(R)
    ylabel('Quantiles of weekly returns')
    title('')
    
    figure
    histogram(MR_earnings,50);
    xlabel('Earnings [USD/day]')
    ylabel('Frequency')
    line([mdn, mdn], ylim, 'LineWidth', 1.5, 'Color', 'r')
    line([avg, avg], ylim,'Color', 'g','LineWidth', 1.5)
    line([prc10, prc10], ylim, 'LineWidth', 1.5, 'Color', 'black')
    line([prc90, prc90], ylim, 'LineWidth', 1.5, 'Color', 'black')
end
end
