% ------------------------------------------------------------------------
%    Script for option to switch fuels, various cases.
%-------------------------------------------------------------------------
clear all
clc
%________________________________________________________________________
% Case 0: Base case. Ship runs on VLSFO only all lifetime, with no
%         possibility to switch fuels.
%_________________________________________________________________________
% Case 1: Ship is able to switch between LPG and VLSFO. Higher machinery
%         cost. VLSFO not compliant at certain point

% Case 2: Originally no fuel flexibility as in case 0. Must retrofit to be
%         compliant. (VLSFO not compliant at certain point) 
% ________________________________________________________________________
% Case 3: Fuel Flexibility LGP/VLSFO, no future regulations stopping VLSFO

%_________________________________________________________________________
Case =2;
nSim = 10000;
rng('default'); % Setting simulation seed for reproducibility

%% Get relevant Case Characteristics

[dr, ir, Vessel_age, T_vessel, PurchasePrice, Vessel_Value,...
    NH3_start, LPG_start, OPEX_nonfuel,...
    VLSFO_start, Consumption, Loan,Drydock_days,Retrofit_cost,...
    Retrofit_year,Equity,Regulation_year,Sailing_days,LPG_lossfactor,...
    Debt_ratio,Steel_price,MachineryAddedCost] = GetCaseCharacteristics(Case);

%% Get Historical Earnings for MR Product Tanker from 1990- April 2020
Plots = 0;
[MR_earnings,year_earnings_MR,year_avg_mr,mr_avg_earnings] = MR_Earnings(Plots);

%% Future Earnings for MR Product Tanker
Plots = 0;

[Sim_Earnings,MeanEarningsRate] = SimulateEarnings(T_vessel,nSim,...
    MR_earnings,year_earnings_MR,year_avg_mr,mr_avg_earnings,Plots);

%% Fuel Statistics
Plots =0;
[FuelDiff,VLSFO,LPG] = SimulateFuelPriceDifference(T_vessel,nSim,...
    LPG_start,VLSFO_start,Plots);

%% VOYEX 
VOYEX_diff = VOYEX2(Case,Consumption,VLSFO,LPG,T_vessel,Retrofit_year,...
    FuelDiff,Regulation_year,Sailing_days,MachineryAddedCost);

%% CAPEX
CAPEX = GetCAPEX(Case,Retrofit_year,Retrofit_cost,Loan,T_vessel,ir);

%% Evaluate cash flows for NPV calculations, base case, no fuel switch 
CF = CashFlow(T_vessel,VOYEX_diff,...
   OPEX_nonfuel,MeanEarningsRate,Loan,Case,Retrofit_year,Drydock_days,...
   CAPEX,Sailing_days,LPG_lossfactor);

%% Discount the calculated cash flows and getting NPV
Plots = 0;
NPV = GetNPV(CF,dr,nSim,T_vessel,Vessel_Value,Equity,Plots);
avg = mean(NPV);
prc10 = prctile(NPV,10);
prc90 = prctile(NPV,90);
if Case == 0
    figure(10)
    hold on
    a = cdfplot(NPV);
    xlabel('NPV [USD]')
    ylabel('Cumulative probability')
    title('')
    legend('Base case','Fuel Flexibility')
    set(a,'Linewidth',1.6);
    avg = mean(NPV);
    prc10 = prctile(NPV,10);
    prc90 = prctile(NPV,90);
    
elseif Case == 3 % Run case 3 after case 0
    figure(10)
    b = cdfplot(NPV);
    xlabel('NPV [USD]')
    ylabel('Cumulative probability')
    xlim([-1e7 2e7])
    title('No regulation requires fuel switch')
    legend('Base case','Flexibility','Location','northwest')
    set(b,'Linewidth',1.6)
end

