% SENSITIVITY ANALYSIS
run NPV_ShipConventional % Case = 0
ENPV_BaseValue = mean(NPV);

% Sensitivity parameters
names = {'Discount rate';'Interest rate';'Daily OPEX';'Sailing days';...
    'Debt ratio';'Purchase Price';'Scrap Value'};
n_param = length(names)*2; % times two bc higher and lower value for each
factor = 0.05;
up = 1+factor;
down = 1-factor;

% Preallocating
ENPV=zeros(1,n_param);
ENPV_up = zeros(1,n_param/2);
ENPV_down = zeros(1,n_param/2);

for i=1:n_param    
[dr, ir, Vessel_age, T_vessel, PurchasePrice, Vessel_Value,NH3_start,...
    LPG_start, OPEX_nonfuel,VLSFO_start, Consumption, Loan,Drydock_days,...
    Retrofit_cost,Retrofit_year,Equity,Regulation_year,Sailing_days,...
    LPG_lossfactor,Debt_ratio,Steel_price,Scrap_value,...
    MachineryAddedCost] = GetCaseCharacteristics(Case);
if i == 1
    dr = dr*down;  
elseif i==2
    dr = dr*up;
elseif i == 3
    ir = ir*down;    
elseif i == 4
    ir = ir*up;
elseif i == 5
    OPEX_nonfuel = OPEX_nonfuel*down;
elseif i == 6
    OPEX_nonfuel = OPEX_nonfuel*up;
elseif i == 7
    Sailing_days = Sailing_days*down;
elseif i == 8
    Sailing_days = Sailing_days*up;
elseif i == 9
    Debt_ratio = Debt_ratio*down;
elseif i == 10
    Debt_ratio = Debt_ratio*up;
elseif i == 11
    PurchasePrice = PurchasePrice*down;
elseif i == 12
    PurchasePrice = PurchasePrice*up;
elseif i == 13
    Scrap_value = Scrap_value*down;
elseif i == 14
    Scrap_value = Scrap_value*up;
end
if i == 9 || i == 10
    Equity = 1 - Debt_ratio;
    Loan = PurchasePrice*Debt_ratio;
elseif i == 11 || i == 12
    Lws = 10375;
    Steel_price = 600;
    Scrap_value = Lws * Steel_price;
    loss_factor = nthroot(Scrap_value/PurchasePrice,T_vessel);
    Vessel_Value  = zeros(1,T_vessel);
    Vessel_Value(1) = PurchasePrice;
    Loan = PurchasePrice*Debt_ratio;
    for j=2:T_vessel
        Vessel_Value(j) = PurchasePrice * loss_factor.^j;
    end
elseif i == 13 || i == 14
    Lws = 10375;
    loss_factor = nthroot(Scrap_value/PurchasePrice,T_vessel);
    Vessel_Value  = zeros(1,T_vessel);
    Vessel_Value(1) = PurchasePrice;
    for j=2:T_vessel
        Vessel_Value(j) = PurchasePrice * loss_factor.^j;
    end
end

VOYEX_diff = VOYEX2(Case,Consumption,VLSFO,LPG,T_vessel,Retrofit_year,...
    FuelDiff,Regulation_year,Sailing_days,MachineryAddedCost);
CAPEX = GetCAPEX(Case,Retrofit_year,Retrofit_cost,Loan,T_vessel,ir);
CF = CashFlow(T_vessel,VOYEX_diff,...
   OPEX_nonfuel,MeanEarningsRate,Loan,Case,Retrofit_year,Drydock_days,...
   CAPEX,Sailing_days,LPG_lossfactor);
NPV = GetNPV(CF,dr,nSim,T_vessel,Vessel_Value,Equity,Plots);

ENPV(i) = mean(NPV);
end

s=1;
for i=1:2:n_param
    ENPV_down(s) = ENPV(i);
    s=s+1;
    if s > n_param/2
        break
    end
end
s=1;
for i=2:2:n_param
    ENPV_up(s) = ENPV(i);
    s=s+1;
    if s > n_param/2
        break
    end
end

ENPV_up_diff = abs(ENPV_up - ENPV_BaseValue) ;
[ENPV_up_diff,index] = sort(ENPV_up_diff,'ascend'); 
ENPV_up = ENPV_up(index);
ENPV_down = ENPV_down(index);
names = names(index);

figure
h = barh(ENPV_up);
bh = get(h,'BaseLine');
set(bh,'BaseValue',ENPV_BaseValue);
hold on
x_min = min(ENPV);
x_max = max(ENPV);
xlim([0.95*x_min 1.05*x_max])
barh(ENPV_down,'r')
set(gca,'yticklabel',names)
set(gca,'Ytick',[1:length(names)],'YTickLabel',[1:length(names)])
set(gca,'yticklabel',names)
legend('5% increase','5% decrease','Location','southeast')
xlabel('Estimated expectation of NPV [USD]')
set(groot,'defaultAxesTickLabelInterpreter','latex');
set(groot,'defaultTextInterpreter','latex') %latex axis labels
set(groot,'defaultLegendInterpreter','latex');
set(gca,'FontSize',12)